@@ -32,8 +32,6 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-util.h>
 #include <gio/gio.h>
 #include <libnautilus-private/nautilus-file.h>
 
@@ -64,10 +62,9 @@ struct NautilusBookmarkDetails
 static void	  nautilus_bookmark_connect_file	  (NautilusBookmark	 *file);
 static void	  nautilus_bookmark_disconnect_file	  (NautilusBookmark	 *file);
 
-GNOME_CLASS_BOILERPLATE (NautilusBookmark, nautilus_bookmark,
-			 GtkObject, GTK_TYPE_OBJECT)
+G_DEFINE_TYPE (NautilusBookmark, nautilus_bookmark, G_TYPE_OBJECT);
 
-/* GtkObject methods.  */
+/* GObject methods.  */
 
 static void
 nautilus_bookmark_finalize (GObject *object)
@@ -88,7 +85,7 @@ nautilus_bookmark_finalize (GObject *object)
 	g_free (bookmark->details->scroll_file);
 	g_free (bookmark->details);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (nautilus_bookmark_parent_class)->finalize (object);
 }
 
 /* Initialization.  */
@@ -119,7 +116,7 @@ nautilus_bookmark_class_init (NautilusBookmarkClass *class)
 }
 
 static void
-nautilus_bookmark_instance_init (NautilusBookmark *bookmark)
+nautilus_bookmark_init (NautilusBookmark *bookmark)
 {
 	bookmark->details = g_new0 (NautilusBookmarkDetails, 1);
 }
@@ -391,13 +388,19 @@ bookmark_file_changed_callback (NautilusFile *file, NautilusBookmark *bookmark)
 	if (nautilus_file_is_gone (file) ||
 	    nautilus_file_is_in_trash (file)) {
 		/* The file we were monitoring has been trashed, deleted,
-		 * or moved in a way that we didn't notice. Make 
+		 * or moved in a way that we didn't notice. We should make 
 		 * a spanking new NautilusFile object for this 
 		 * location so if a new file appears in this place 
-		 * we will notice.
+		 * we will notice. However, we can't immediately do so
+		 * because creating a new NautilusFile directly as a result
+		 * of noticing a file goes away may trigger i/o on that file
+		 * again, noticeing it is gone, leading to a loop.
+		 * So, the new NautilusFile is created when the bookmark
+		 * is used again. However, this is not really a problem, as
+		 * we don't want to change the icon or anything about the
+		 * bookmark just because its not there anymore.
 		 */
 		nautilus_bookmark_disconnect_file (bookmark);
-		should_emit_appearance_changed_signal = TRUE;		
 	} else if (nautilus_bookmark_update_icon (bookmark)) {
 		/* File hasn't gone away, but it has changed
 		 * in a way that affected its icon.
